==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/PersistenceParser__24DoubleHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$DoubleHandlerCreator

// class file dependencies
// @dep_class e3696642f9d826d4 gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *);

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/PersistenceParser__24DoubleHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$DoubleHandlerCreator

// class file dependencies
// @dep_class 525a28c2d71513d0 gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24DoubleHandlerCreator_H_ */
